this is the virtual assistant that can speak and listen it can be easily used by just calling one function that is main()
just call main and it will begain. Some people can face problem in installing speech_recognition library or pyaudio
i am providing the link to video how to overcome that issue :- https://www.youtube.com/watch?v=-3am_5jMzJ4
NOTE: i have'nt made this video but this is best suited solution after installing pyaudio you can easilly install this module.
to use this assistant as whole you just need to do so!
from talking_assist import shubham_assist as sj
sj.main()
and boom it will start. hope you will enjoy.